import sys
import uuid

from confluent_kafka import Consumer

niter = int(sys.argv[1]) if len(sys.argv) > 1 else 5

topics = ["test_topic"]

config = {
    "bootstrap.servers": "localhost:9092",
    "group.id": uuid.uuid4(),
    "auto.offset.reset": "earliest",
    "enable.auto.commit": False,
    "max.poll.interval.ms": 6000,
    "session.timeout.ms": 6000,
    "connections.max.idle.ms": 6000,
    "metadata.max.age.ms": 6000,
    "debug": "consumer",
}


def drain(consumer):
    while consumer.poll(timeout=1):
        pass


def lost_handler(*args, **kwargs):
    print("on loss", flush=True)


def assign_handler(*args, **kwargs):
    print("on assign", flush=True)


def revoke_handler(*args, **kwargs):
    print("on revoke", flush=True)


consumer = Consumer(config)
consumer.subscribe(
    topics,
    on_assign=assign_handler,
    on_lost=lost_handler,
    on_revoke=revoke_handler,
)
drain(consumer)
for i in range(1, niter):
    message = consumer.poll(timeout=5)
    if message:
        print("message=", message.value(), "error=", message.error(), flush=True)
    else:
        print("message=", message, flush=True)

    print("assignment=", consumer.assignment(), flush=True)
    print("list_topics=", consumer.list_topics(topics[0]).topics, flush=True)
    print("========", flush=True)

    # verbose_logging(consumer)


consumer.close()
print("closed", flush=True)
consumer
